@@ -25,25 +25,9 @@ sub extract {
 sub source {
     my $class = ref $_[0] || $_[0];
     no strict 'refs';
-
     return ${"$class\::Remote"}{source};
 }
 
-sub sources {
-    my $class = ref $_[0] || $_[0];
-    no strict 'refs';
-
-    my $src = ${"$class\::Remote"}{source};
-    if ( ref $src eq 'ARRAY' ) {
-        return @$src;
-    }
-    elsif ( ref $src eq 'HASH' ) {
-        return
-            map { ref $_ ? @$_ : $_ } $_[1] ? $src->{ $_[1] } : values %$src;
-    }
-    return $src;
-}
-
 sub has_remotelist { return defined $_[0]->source(); }
 
 # main method: return the list from the remote source
@@ -52,37 +36,24 @@ sub remote_list {
     return unless $class->has_remotelist();
 
     # check that we can access the network
-    eval {
-        require LWP::UserAgent;
-        die "version 5.802 required ($LWP::VERSION installed)\n"
-            if $LWP::VERSION < 5.802;
-    };
+    eval { require LWP::Simple; };
     if ($@) {
-        carp "LWP::UserAgent not available: $@";
+        carp "LWP::Simple not available: $@";
         return;
     }
 
     # fetch the content
-    my @items;
-    my @srcs = $class->sources($_[1]);
-    my $ua   = LWP::UserAgent->new( env_proxy => 1 );
-    foreach my $src (@srcs) {
-        my $res  = $ua->request( HTTP::Request->new( GET => $src ) );
-        if ( ! $res->is_success() ) {
-            carp "Failed to get content at $src (" . $res->status_line();
-            return;
-        }
-
-        # extract, cleanup and return the data
-        # if decoding the content fails, we just deal with the raw content
-        push @items =>
-            $class->extract( $res->decoded_content() || $res->content() );
-
+    my $src     = $class->source();
+    my $content = LWP::Simple::get($src);
+    if ( !defined $content ) {
+        carp "Failed to get content at $src";
+        return;
     }
 
-    # return unique items
-    my %seen;
-    return grep { !$seen{$_}++ } @items;
+    # extract, cleanup and return the data
+    my @items = $class->extract($content);
+
+    return @items;
 }
 
 #
@@ -101,35 +72,6 @@ sub tr_accent {
     return $str;
 }
 
-my %utf2asc = (
-    "\xc3\x89" => 'E',
-    "\xc3\xa0" => 'a',
-    "\xc3\xa1" => 'a',
-    "\xc3\xa9" => 'e',
-    "\xc3\xaf" => 'i',
-    "\xc3\xad" => 'i',
-    "\xc3\xb6" => 'o',
-    "\xc3\xb8" => 'o',
-    "\xc5\xa0" => 'S',
-    "\x{0160}" => 'S',
-    # for pokemons
-    "\x{0101}"     => 'a',
-    "\x{012b}"     => 'i',
-    "\x{014d}"     => 'o',
-    "\x{016b}"     => 'u',
-    "\xe2\x99\x80" => 'female',
-    "\xe2\x99\x82" => 'male',
-    "\x{2640}"     => 'female',
-    "\x{2642}"     => 'male',
-);
-my $utf_re = qr/(@{[join( '|', sort keys %utf2asc )]})/; 
-
-sub tr_utf8_basic {
-    my $str = shift;
-    $str =~ s/$utf_re/$utf2asc{$1}/go;
-    return $str;
-}
-
 1;
 
 __END__
@@ -180,8 +122,6 @@ The keys are:
 =item C<source>
 
 The URL where the data is available.
-This can also be an array reference containing several URLs, whose
-content will be passed to the C<extract> subroutine.
 
 =item C<extract>
 
@@ -216,17 +156,7 @@ if the theme actually has a remote list).
 
 =item source()
 
-Return the data structure containing the source URLs. This can be quite
-different depending on the class: a single scalar (URL), an array
-reference (list of URLs) or a hash reference (each value being either
-a scalar or an array reference) for themes that are subclasses of
-C<Acme::MetaSyntactic::MultiList>.
-
-=item sources( [ $category ] )
-
-Return the list of source URL. The C<$category> parameter can be used
-to select the sources for a sub-category of the theme (in the case of
-C<Acme::MetaSyntactic::MultiList>).
+Return the source URL.
 
 =item extract( $content )
 
@@ -252,12 +182,6 @@ underscores (C<_>).
 Return a copy of C<$str> will all iso-8859-1 accented characters turned
 into basic ASCII characters.
 
-=item tr_utf8_basic( $str )
-
-Return a copy of C<$str> with some of the utf-8 accented characters turned
-into basic ASCII characters. This is very crude, but I didn't to bother
-and depend on the proper module to do that.
-
 =back
 
 =head1 AUTHOR
@@ -282,7 +206,7 @@ L<Acme::MetaSyntactic::Locale>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005-2006 Philippe 'BooK' Bruhat, All Rights Reserved.
+Copyright 2005 Philippe 'BooK' Bruhat, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
